use Module::Build;
 
Module::Build -> new(
	module_name    	=> 'Hash::MD5',
	license        	=> 'artistic_2',
	dist_abstract  	=> 'MD5 checksum for choosen hashref',
	dist_author    	=> 'Mario Zieschang <mario_zieschang@web.de>',
	build_requires 	=> {
		Test::More				=> 0,
		FindBin 				=> 0,
		Test::Pod				=> 1.22,
		Test::Pod::Coverage		=> 1.08,
		Pod::Coverage::TrustPod	=> 0.100003,
		Test::CheckManifest 	=> 0.9,
	},
	configure_requires 	=> {
		Module::Build 	=> 0.3800,
	},
	requires => {
		Digest::MD5 => 0,
		Exporter 	=> 0,
	},
) -> create_build_script();