#!perl
# This file was automatically generated by Dist::Zilla::Plugin::PodCoverageTests.

use FindBin;
use lib "$FindBin::Bin/../lib";
use Test::More;

use Test::Pod::Coverage 1.08;
use Pod::Coverage::TrustPod;

unless ( $ENV{RELEASE_TESTING} ) {
    plan( skip_all => "Author tests not required for installation" );
}

all_pod_coverage_ok({ coverage_class => 'Pod::Coverage::TrustPod' });
